@@ -42,8 +42,6 @@ pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
 pub mod event_source_enum;
 pub use self::event_source_enum::EventSourceEnum;
-pub mod event_type0c4_enum;
-pub use self::event_type0c4_enum::EventType0c4Enum;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
@@ -58,6 +56,10 @@ pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
 pub use self::model_artifact::ModelArtifact;
+pub mod octo_generic_event;
+pub use self::octo_generic_event::OctoGenericEvent;
+pub mod octo_job_event;
+pub use self::octo_job_event::OctoJobEvent;
 pub mod octo_print_device;
 pub use self::octo_print_device::OctoPrintDevice;
 pub mod octo_print_device_key;
@@ -66,10 +68,14 @@ pub mod octo_print_device_request;
 pub use self::octo_print_device_request::OctoPrintDeviceRequest;
 pub mod octo_print_event;
 pub use self::octo_print_event::OctoPrintEvent;
-pub mod octo_print_event_event_type_enum;
-pub use self::octo_print_event_event_type_enum::OctoPrintEventEventTypeEnum;
 pub mod octo_print_event_request;
 pub use self::octo_print_event_request::OctoPrintEventRequest;
+pub mod octo_print_nanny_event;
+pub use self::octo_print_nanny_event::OctoPrintNannyEvent;
+pub mod octo_printer_event;
+pub use self::octo_printer_event::OctoPrinterEvent;
+pub mod octo_telemetry_event;
+pub use self::octo_telemetry_event::OctoTelemetryEvent;
 pub mod octoprint_environment;
 pub use self::octoprint_environment::OctoprintEnvironment;
 pub mod octoprint_environment_request;
@@ -148,8 +154,6 @@ pub mod paginated_printer_controller_list;
 pub use self::paginated_printer_controller_list::PaginatedPrinterControllerList;
 pub mod paginated_printer_profile_list;
 pub use self::paginated_printer_profile_list::PaginatedPrinterProfileList;
-pub mod paginated_release_list;
-pub use self::paginated_release_list::PaginatedReleaseList;
 pub mod paginated_remote_command_event_list;
 pub use self::paginated_remote_command_event_list::PaginatedRemoteCommandEventList;
 pub mod paginated_remote_control_command_list;
@@ -198,14 +202,10 @@ pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
 pub use self::print_job_event_request::PrintJobEventRequest;
-pub mod print_job_event_type;
-pub use self::print_job_event_type::PrintJobEventType;
 pub mod print_nanny_api_config;
 pub use self::print_nanny_api_config::PrintNannyApiConfig;
 pub mod print_nanny_plugin_event;
 pub use self::print_nanny_plugin_event::PrintNannyPluginEvent;
-pub mod print_nanny_plugin_event_event_type_enum;
-pub use self::print_nanny_plugin_event_event_type_enum::PrintNannyPluginEventEventTypeEnum;
 pub mod print_nanny_plugin_event_request;
 pub use self::print_nanny_plugin_event_request::PrintNannyPluginEventRequest;
 pub mod print_session;
@@ -224,16 +224,10 @@ pub mod printer_profile;
 pub use self::printer_profile::PrinterProfile;
 pub mod printer_profile_request;
 pub use self::printer_profile_request::PrinterProfileRequest;
-pub mod printer_state_enum;
-pub use self::printer_state_enum::PrinterStateEnum;
 pub mod printnanny_env_enum;
 pub use self::printnanny_env_enum::PrintnannyEnvEnum;
-pub mod release;
-pub use self::release::Release;
 pub mod release_channel_enum;
 pub use self::release_channel_enum::ReleaseChannelEnum;
-pub mod release_request;
-pub use self::release_request::ReleaseRequest;
 pub mod remote_command_event;
 pub use self::remote_command_event::RemoteCommandEvent;
 pub mod remote_command_event_event_type_enum;
@@ -264,8 +258,6 @@ pub mod task_type;
 pub use self::task_type::TaskType;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
-pub mod telemetry_event_event_type_enum;
-pub use self::telemetry_event_event_type_enum::TelemetryEventEventTypeEnum;
 pub mod telemetry_event_polymorphic;
 pub use self::telemetry_event_polymorphic::TelemetryEventPolymorphic;
 pub mod telemetry_event_polymorphic_request;
@@ -278,5 +270,3 @@ pub mod user;
 pub use self::user::User;
 pub mod user_request;
 pub use self::user_request::UserRequest;
-pub mod variant_enum;
-pub use self::variant_enum::VariantEnum;
